Python module to read data from Bluetooth Smart sensors.

Features

1. Devices and sensor readings

   - SimpleLink SensorTag (CC2541DK, CC2650STK)

     - temperature
     - pressure
     - humidity
     - light (CC2541DK only)
     - accelerometer (CC2541DK only)
     - buttons (CC2541DK only)

2. Sensor data access using `asyncio` coroutines.

Table of Contents
-----------------

.. toctree::
   use
   api
   changelog

* :ref:`genindex`
* :ref:`search`

.. vim: sw=4:et:ai
